#!/bin/bash -e

echo "================= Adding some global settings ==================="
mkdir -p "$HOME/.ssh/"
mv /c8/config "$HOME/.ssh/"
touch "$HOME/.ssh/known_hosts"
mkdir -p /etc/drydock

echo "================= Installing basic packages ================"

dnf -y install  \
sudo \
wget \
unzip \
curl \
openssh-clients \
ftp \
gettext \
samba-client \
openssl \
which \
mercurial

echo "================= Installing Python packages ==================="
sudo dnf install -y epel-release
sudo dnf install -y \
  python3-devel \
  python3-pip

sudo pip3 install virtualenv==20.4.7
sudo pip3 install cryptography==3.3.2
sudo pip3 install -q pyOpenSSL==20.0.1

export JQ_VERSION=1.5*
echo "================= Adding JQ $JQ_VERSION ==================="
sudo dnf install epel-release -y
sudo dnf install -y jq-"$JQ_VERSION"

echo "================= Installing CLIs packages ======================"

export GIT_VERSION=2.27*
echo "================= Installing Git $GIT_VERSION ===================="
sudo dnf install -y git-"$GIT_VERSION"

echo "================= Installing Git lfs ===================="
sudo rpm -i c8/gitlfs.rpm

echo "================= Adding gcloud =================="
tar -xf /c8/gcloudsdk.tar.gz
sudo ./google-cloud-sdk/install.sh -q
echo "source /google-cloud-sdk/path.bash.inc"  >> ~/.bashrc

export AWS_VERSION=1.19.103
echo "================= Adding awscli $AWS_VERSION ===================="
sudo pip3 install awscli=="$AWS_VERSION"

AZURE_CLI_VERSION=2.25*
echo "================ Adding azure-cli $AZURE_CLI_VERSION  =============="
sudo rpm --import https://packages.microsoft.com/keys/microsoft.asc
sudo sh -c 'echo -e "[azure-cli]\nname=Azure CLI\nbaseurl=https://packages.microsoft.com/yumrepos/azure-cli\nenabled=1\ngpgcheck=1\ngpgkey=https://packages.microsoft.com/keys/microsoft.asc" > /etc/yum.repos.d/azure-cli.repo'
sudo yum install -y azure-cli-$AZURE_CLI_VERSION

export JFROG_VERSION=1.50.0
echo "================= Adding jfrog-cli $JFROG_VERSION==================="
wget -nv https://releases.jfrog.io/artifactory/jfrog-cli/v1/"$JFROG_VERSION"/jfrog-cli-linux-amd64/jfrog?bt_package=jfrog-cli-linux-amd64 -O jfrog
sudo chmod +x jfrog
sudo mv jfrog /usr/bin/jfrog

KUBECTL_VERSION=1.21.0
echo "================= Adding kubectl "$KUBECTL_VERSION" ==================="
curl -LO https://storage.googleapis.com/kubernetes-release/release/v"$KUBECTL_VERSION"/bin/linux/amd64/kubectl
sudo chmod +x ./kubectl
sudo mv ./kubectl /usr/local/bin/kubectl

HELM_VERSION=3.6.2
echo "================= Adding helm cli $HELM_VERSION ======================================"
curl -sSL -o helm.tar.gz https://get.helm.sh/helm-v"$HELM_VERSION"-linux-amd64.tar.gz
tar xzvf helm.tar.gz
chmod +x ./linux-amd64/helm
sudo mv ./linux-amd64/helm /usr/local/bin/helm
rm -fr ./linux-amd64
rm -f helm.tar.gz

TF_VERSION=1.0.4
echo "================ Adding terraform- $TF_VERSION  ===================="
TF_FILE=terraform_"$TF_VERSION"_linux_amd64.zip

echo "Fetching terraform"
echo "-----------------------------------"
rm -rf /tmp/terraform
mkdir -p /tmp/terraform
wget -nv https://releases.hashicorp.com/terraform/$TF_VERSION/$TF_FILE
unzip -o $TF_FILE -d /tmp/terraform
sudo chmod +x /tmp/terraform/terraform
mv /tmp/terraform/terraform /usr/bin/terraform

PK_VERSION=1.7.3
echo "================ Adding packer $PK_VERSION  ===================="
PK_FILE=packer_"$PK_VERSION"_linux_amd64.zip

echo "Fetching packer"
echo "-----------------------------------"
rm -rf /tmp/packer
mkdir -p /tmp/packer
wget -nv https://releases.hashicorp.com/packer/$PK_VERSION/$PK_FILE
unzip -o $PK_FILE -d /tmp/packer
sudo chmod +x /tmp/packer/packer
mv /tmp/packer/packer /usr/bin/packer

echo "======= Adding docker compose ======="
sudo mv /c8/docker-compose /usr/local/bin/docker-compose
sudo chmod +x /usr/local/bin/docker-compose

export ANSIBLE_VERSION=4.4.0
echo "================ Adding ansible $ANSIBLE_VERSION =============================="
sudo pip3 install ansible=="$ANSIBLE_VERSION"

HELM_VERSION=3.6.2
echo "================= Adding helm cli $HELM_VERSION ======================================"
curl -sSL -o helm.tar.gz https://get.helm.sh/helm-v"$HELM_VERSION"-linux-amd64.tar.gz
tar xzvf helm.tar.gz
chmod +x ./linux-amd64/helm
sudo mv ./linux-amd64/helm /usr/local/bin/helm
rm -fr ./linux-amd64
rm -f helm.tar.gz
